/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.text.resources.cldr.ext;

import java.util.ListResourceBundle;

public class FormatData_mr extends ListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] metaValue_MonthNames = new String[] {
               "\u091c\u093e\u0928\u0947\u0935\u093e\u0930\u0940",
               "\u092b\u0947\u092c\u094d\u0930\u0941\u0935\u093e\u0930\u0940",
               "\u092e\u093e\u0930\u094d\u091a",
               "\u090f\u092a\u094d\u0930\u093f\u0932",
               "\u092e\u0947",
               "\u091c\u0942\u0928",
               "\u091c\u0941\u0932\u0948",
               "\u0911\u0917\u0938\u094d\u091f",
               "\u0938\u092a\u094d\u091f\u0947\u0902\u092c\u0930",
               "\u0911\u0915\u094d\u091f\u094b\u092c\u0930",
               "\u0928\u094b\u0935\u094d\u0939\u0947\u0902\u092c\u0930",
               "\u0921\u093f\u0938\u0947\u0902\u092c\u0930",
               "",
            };
        final String[] metaValue_MonthAbbreviations = new String[] {
               "\u091c\u093e\u0928\u0947",
               "\u092b\u0947\u092c\u094d\u0930\u0941",
               "\u092e\u093e\u0930\u094d\u091a",
               "\u090f\u092a\u094d\u0930\u093f",
               "\u092e\u0947",
               "\u091c\u0942\u0928",
               "\u091c\u0941\u0932\u0948",
               "\u0911\u0917",
               "\u0938\u092a\u094d\u091f\u0947\u0902",
               "\u0911\u0915\u094d\u091f\u094b",
               "\u0928\u094b\u0935\u094d\u0939\u0947\u0902",
               "\u0921\u093f\u0938\u0947\u0902",
               "",
            };
        final String[] metaValue_MonthNarrows = new String[] {
               "\u091c\u093e",
               "\u092b\u0947",
               "\u092e\u093e",
               "\u090f",
               "\u092e\u0947",
               "\u091c\u0942",
               "\u091c\u0941",
               "\u0911",
               "\u0938",
               "\u0911",
               "\u0928\u094b",
               "\u0921\u093f",
               "",
            };
        final String[] metaValue_DayNames = new String[] {
               "\u0930\u0935\u093f\u0935\u093e\u0930",
               "\u0938\u094b\u092e\u0935\u093e\u0930",
               "\u092e\u0902\u0917\u0933\u0935\u093e\u0930",
               "\u092c\u0941\u0927\u0935\u093e\u0930",
               "\u0917\u0941\u0930\u0941\u0935\u093e\u0930",
               "\u0936\u0941\u0915\u094d\u0930\u0935\u093e\u0930",
               "\u0936\u0928\u093f\u0935\u093e\u0930",
            };
        final String[] metaValue_DayAbbreviations = new String[] {
               "\u0930\u0935\u093f",
               "\u0938\u094b\u092e",
               "\u092e\u0902\u0917\u0933",
               "\u092c\u0941\u0927",
               "\u0917\u0941\u0930\u0941",
               "\u0936\u0941\u0915\u094d\u0930",
               "\u0936\u0928\u093f",
            };
        final String[] metaValue_DayNarrows = new String[] {
               "\u0930",
               "\u0938\u094b",
               "\u092e\u0902",
               "\u092c\u0941",
               "\u0917\u0941",
               "\u0936\u0941",
               "\u0936",
            };
        final String[] metaValue_QuarterNames = new String[] {
               "\u092a\u094d\u0930\u0925\u092e \u0924\u093f\u092e\u093e\u0939\u0940",
               "\u0926\u094d\u0935\u093f\u0924\u0940\u092f \u0924\u093f\u092e\u093e\u0939\u0940",
               "\u0924\u0943\u0924\u0940\u092f \u0924\u093f\u092e\u093e\u0939\u0940",
               "\u091a\u0924\u0941\u0930\u094d\u0925 \u0924\u093f\u092e\u093e\u0939\u0940",
            };
        final String[] metaValue_QuarterAbbreviations = new String[] {
               "\u0924\u093f\u0967",
               "\u0924\u093f\u0968",
               "\u0924\u093f\u0969",
               "\u0924\u093f\u096a",
            };
        final String[] metaValue_QuarterNarrows = new String[] {
               "\u0967",
               "\u0968",
               "\u0969",
               "\u096a",
            };
        final String[] metaValue_AmPmMarkers = new String[] {
               "\u092e.\u092a\u0942.",
               "\u092e.\u0909.",
            };
        final String[] metaValue_narrow_AmPmMarkers = new String[] {
               "\u0938",
               "\u0938\u0902",
            };
        final String[] metaValue_Eras = new String[] {
               "\u0907. \u0938. \u092a\u0942.",
               "\u0907. \u0938.",
            };
        final String[] metaValue_TimePatterns = new String[] {
               "h:mm:ss a zzzz",
               "h:mm:ss a z",
               "h:mm:ss a",
               "h:mm a",
            };
        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
               "BC",
               "\u0907\u0938\u0935\u0940\u0938\u0928 \u092a\u0942\u0930\u094d\u0935",
            };
        final String[] metaValue_java_time_buddhist_Eras = new String[] {
               "BC",
               "\u0907\u0938\u092a\u0942.",
            };
        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
               "EEEE, d MMMM, y G",
               "d MMMM, y G",
               "d MMM, y G",
               "d/M/y GGGGG",
            };
        final String[] metaValue_buddhist_DatePatterns = new String[] {
               "EEEE, d MMMM, y GGGG",
               "d MMMM, y GGGG",
               "d MMM, y GGGG",
               "d/M/y G",
            };
        final String[] metaValue_java_time_roc_long_Eras = new String[] {
               "\u0906\u0930.\u0913.\u0938\u0940. \u0906\u0927\u0940",
               "\u092e\u093f\u0902\u0917\u0942",
            };
        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
               "",
               "\u0939\u093f\u091c\u0930\u0940 \u0935\u0930\u094d\u0937",
            };
        final String[] metaValue_java_time_islamic_Eras = new String[] {
               "",
               "\u0939\u093f.\u0935.",
            };
        final String metaValue_calendarname_gregorian = "\u0917\u094d\u0930\u0947\u0917\u094b\u0930\u093f\u092f\u0928 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e";
        final Object[][] data = new Object[][] {
            { "MonthNames", metaValue_MonthNames },
            { "field.year", "\u0935\u0930\u094d\u0937" },
            { "calendarname.islamic-umalqura", "\u092e\u0941\u0938\u094d\u0932\u093f\u092e \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e \u0909\u092e-\u0905\u0932-\u0915\u0941\u0930\u093e" },
            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
            { "AmPmMarkers", metaValue_AmPmMarkers },
            { "timezone.gmtFormat", "[GMT]{0}" },
            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.QuarterNames", metaValue_QuarterNames },
            { "roc.MonthNarrows", metaValue_MonthNarrows },
            { "calendarname.islamic-civil", "\u092e\u0941\u0938\u094d\u0932\u093f\u092e- \u0928\u093e\u0917\u0930\u0940 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
            { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
            { "japanese.TimePatterns", metaValue_TimePatterns },
            { "narrow.Eras", metaValue_Eras },
            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
            { "timezone.regionFormat.standard", "{0} \u092a\u094d\u0930\u092e\u093e\u0923 \u0935\u0947\u0933" },
            { "DefaultNumberingSystem", "deva" },
            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
            { "calendarname.japanese", "\u091c\u092a\u093e\u0928\u0940 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
            { "timezone.gmtZeroFormat", "[GMT]" },
            { "japanese.MonthNames", metaValue_MonthNames },
            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
            { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
            { "long.Eras",
                new String[] {
                    "\u0908\u0938\u0935\u0940\u0938\u0928\u092a\u0942\u0930\u094d\u0935",
                    "\u0908\u0938\u0935\u0940\u0938\u0928",
                }
            },
            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
            { "islamic.DayNames", metaValue_DayNames },
            { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "buddhist.MonthNames", metaValue_MonthNames },
            { "DateTimePatterns",
                new String[] {
                    "{1} \u0930\u094b\u091c\u0940 {0}",
                    "{1} \u0930\u094b\u091c\u0940 {0}",
                    "{1}, {0}",
                    "{1}, {0}",
                }
            },
            { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
            { "latn.NumberElements",
                new String[] {
                    ".",
                    ",",
                    ";",
                    "%",
                    "0",
                    "#",
                    "-",
                    "E",
                    "\u2030",
                    "\u221e",
                    "NaN",
                    "",
                    "",
                }
            },
            { "MonthNarrows", metaValue_MonthNarrows },
            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
            { "buddhist.DayNames", metaValue_DayNames },
            { "field.minute", "\u092e\u093f\u0928\u093f\u091f" },
            { "field.era", "\u092f\u0941\u0917" },
            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
            { "field.dayperiod", "[\u092e.\u092a\u0942./\u092e.\u0909.]" },
            { "standalone.MonthNarrows", metaValue_MonthNarrows },
            { "islamic.MonthNames",
                new String[] {
                    "\u092e\u094b\u0939\u0930\u092e",
                    "\u0938\u092b\u0930",
                    "\u0930\u093e\u092c\u0940 I",
                    "\u0930\u093e\u092c\u0940 II",
                    "\u091c\u0941\u092e\u093e\u0926\u093e I",
                    "\u091c\u0941\u092e\u093e\u0926\u093e II",
                    "\u0930\u091d\u093e\u092c",
                    "\u0936\u093e\u092c\u093e\u0928",
                    "\u0930\u092e\u091c\u093e\u0928",
                    "\u0936\u0935\u094d\u0935\u093e\u0932",
                    "\u0927\u0941\u0932-\u0915\u0940\u0926\u093e\u0939",
                    "\u0927\u0941\u0932-\u0939\u093f\u091c\u093e\u0939",
                    "",
                }
            },
            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
            { "calendarname.roc", "\u092e\u093f\u0928\u0917\u0941\u0913 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
            { "deva.NumberElements",
                new String[] {
                    ".",
                    ",",
                    ";",
                    "%",
                    "\u0966",
                    "#",
                    "-",
                    "E",
                    "\u2030",
                    "\u221e",
                    "NaN",
                    "",
                    "",
                }
            },
            { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "islamic.Eras", metaValue_java_time_islamic_Eras },
            { "field.month", "\u092e\u0939\u093f\u0928\u093e" },
            { "roc.Eras", metaValue_java_time_roc_long_Eras },
            { "field.second", "\u0938\u0947\u0915\u0902\u0926" },
            { "islamic.MonthNarrows",
                new String[] {
                    "\u0967",
                    "\u0968",
                    "\u0969",
                    "\u096a",
                    "\u096b",
                    "\u096c",
                    "\u096d",
                    "\u096e",
                    "\u096f",
                    "\u0967\u0966",
                    "\u0967\u0967",
                    "\u0967\u0968",
                    "",
                }
            },
            { "DayAbbreviations", metaValue_DayAbbreviations },
            { "DayNarrows", metaValue_DayNarrows },
            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
            { "calendarname.islamic", "\u092e\u0941\u0938\u094d\u0932\u093f\u092e \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
            { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
            { "buddhist.TimePatterns", metaValue_TimePatterns },
            { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "timezone.regionFormat", "{0} \u0935\u0947\u0933" },
            { "long.CompactNumberPatterns",
                new String[] {
                    "",
                    "",
                    "",
                    "{one:0' '\u0939\u091c\u093e\u0930 other:0' '\u0939\u091c\u093e\u0930}",
                    "{one:00' '\u0939\u091c\u093e\u0930 other:00' '\u0939\u091c\u093e\u0930}",
                    "{one:0' '\u0932\u093e\u0916 other:0' '\u0932\u093e\u0916}",
                    "{one:00' '\u0932\u093e\u0916 other:00' '\u0932\u093e\u0916}",
                    "{one:0' '\u0915\u094b\u091f\u0940 other:0' '\u0915\u094b\u091f\u0940}",
                    "{one:00' '\u0915\u094b\u091f\u0940 other:00' '\u0915\u094b\u091f\u0940}",
                    "{one:0' '\u0905\u092c\u094d\u091c other:0' '\u0905\u092c\u094d\u091c}",
                    "{one:00' '\u0905\u092c\u094d\u091c other:00' '\u0905\u092c\u094d\u091c}",
                    "{one:0' '\u0916\u0930\u094d\u0935 other:0' '\u0916\u0930\u094d\u0935}",
                    "{one:00' '\u0916\u0930\u094d\u0935 other:00' '\u0916\u0930\u094d\u0935}",
                    "{one:0' '\u092a\u0926\u094d\u092e other:0' '\u092a\u0926\u094d\u092e}",
                    "{one:00' '\u092a\u0926\u094d\u092e other:00' '\u092a\u0926\u094d\u092e}",
                }
            },
            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
            { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
            { "standalone.QuarterNames", metaValue_QuarterNames },
            { "japanese.MonthNarrows", metaValue_MonthNarrows },
            { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
            { "standalone.DayNarrows", metaValue_DayNarrows },
            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
            { "TimePatterns", metaValue_TimePatterns },
            { "islamic.DayNarrows", metaValue_DayNarrows },
            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
            { "field.zone", "\u0935\u0947\u0933 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
            { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
            { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
            { "Eras", metaValue_Eras },
            { "roc.DayNames", metaValue_DayNames },
            { "islamic.QuarterNames", metaValue_QuarterNames },
            { "QuarterNarrows", metaValue_QuarterNarrows },
            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
            { "standalone.QuarterNarrows", metaValue_QuarterNarrows },
            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
            { "field.weekday", "\u0906\u0920\u0935\u0921\u094d\u092f\u093e\u091a\u093e \u0926\u093f\u0935\u0938" },
            { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
            { "java.time.islamic.Eras", metaValue_java_time_islamic_Eras },
            { "japanese.QuarterNames", metaValue_QuarterNames },
            { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_Eras },
            { "japanese.DayNames", metaValue_DayNames },
            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
            { "DayNames", metaValue_DayNames },
            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
            { "roc.MonthNames", metaValue_MonthNames },
            { "buddhist.Eras", metaValue_java_time_buddhist_Eras },
            { "field.week", "\u0906\u0920\u0935\u0921\u093e" },
            { "buddhist.MonthNarrows", metaValue_MonthNarrows },
            { "buddhist.QuarterNames", metaValue_QuarterNames },
            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
            { "roc.DayNarrows", metaValue_DayNarrows },
            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
            { "short.CompactNumberPatterns",
                new String[] {
                    "",
                    "",
                    "",
                    "{one:0\u00a0\u0939 other:0\u00a0\u0939}",
                    "{one:00\u00a0\u0939 other:00\u00a0\u0939}",
                    "{one:0\u00a0\u0932\u093e\u0916 other:0\u00a0\u0932\u093e\u0916}",
                    "{one:00\u00a0\u0932\u093e\u0916 other:00\u00a0\u0932\u093e\u0916}",
                    "{one:0\u00a0\u0915\u094b\u091f\u0940 other:0\u00a0\u0915\u094b\u091f\u0940}",
                    "{one:00\u00a0\u0915\u094b\u091f\u0940 other:00\u00a0\u0915\u094b\u091f\u0940}",
                    "{one:0\u00a0\u0905\u092c\u094d\u091c other:0\u00a0\u0905\u092c\u094d\u091c}",
                    "{one:00\u00a0\u0905\u092c\u094d\u091c other:00\u00a0\u0905\u092c\u094d\u091c}",
                    "{one:0\u00a0\u0916\u0930\u094d\u0935 other:0\u00a0\u0916\u0930\u094d\u0935}",
                    "{one:00\u00a0\u0916\u0930\u094d\u0935 other:00\u00a0\u0916\u0930\u094d\u0935}",
                    "{one:0\u00a0\u092a\u0926\u094d\u092e other:0\u00a0\u092a\u0926\u094d\u092e}",
                    "{one:00\u00a0\u092a\u0926\u094d\u092e other:00\u00a0\u092a\u0926\u094d\u092e}",
                }
            },
            { "calendarname.gregorian", metaValue_calendarname_gregorian },
            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_Eras },
            { "timezone.regionFormat.daylight", "{0} \u0938\u0942\u0930\u094d\u092f\u092a\u094d\u0930\u0915\u093e\u0936 \u0935\u0947\u0933" },
            { "DatePatterns",
                new String[] {
                    "EEEE, d MMMM, y",
                    "d MMMM, y",
                    "d MMM, y",
                    "d/M/yy",
                }
            },
            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
            { "islamic.TimePatterns", metaValue_TimePatterns },
            { "MonthAbbreviations", metaValue_MonthAbbreviations },
            { "standalone.DayNames", metaValue_DayNames },
            { "field.hour", "\u0924\u093e\u0938" },
            { "islamic.MonthAbbreviations",
                new String[] {
                    "\u092e\u094b\u0939.",
                    "\u0938\u092b.",
                    "\u0930\u093e\u092c\u0940 I",
                    "\u0930\u093e\u092c\u0940 II",
                    "\u091c\u0941\u092e\u093e. I",
                    "\u091c\u0941\u092e\u093e. II",
                    "\u0930\u091d\u093e.",
                    "\u0936\u093e\u092c\u093e.",
                    "\u0930\u092e.",
                    "\u0936\u0935\u094d\u0935\u093e.",
                    "\u0927\u0941\u0932-\u0915\u0940.",
                    "\u0927\u0941\u0932-\u0939\u093f.",
                    "",
                }
            },
            { "islamic.narrow.Eras", metaValue_java_time_islamic_Eras },
            { "calendarname.buddhist", "\u092c\u094c\u0926\u094d\u0927 \u0926\u093f\u0928\u0926\u0930\u094d\u0936\u093f\u0915\u093e" },
            { "standalone.MonthNames", metaValue_MonthNames },
            { "latn.NumberPatterns",
                new String[] {
                    "#,##,##0.###",
                    "\u00a4#,##0.00",
                    "#,##0%",
                    "\u00a4#,##0.00;(\u00a4#,##0.00)",
                }
            },
            { "buddhist.DayNarrows", metaValue_DayNarrows },
            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
            { "japanese.DayNarrows", metaValue_DayNarrows },
            { "QuarterNames", metaValue_QuarterNames },
            { "roc.TimePatterns", metaValue_TimePatterns },
            { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
            { "deva.NumberPatterns",
                new String[] {
                    "#,##,##0.###",
                    "\u00a4#,##0.00",
                    "#,##0%",
                    "",
                }
            },
            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
            { "calendarname.gregory", metaValue_calendarname_gregorian },
        };
        return data;
    }
}
